.. nova-trame documentation master file, created by
   sphinx-quickstart on Mon Sep 30 16:18:03 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

==========================================
NOVA application development documentation
==========================================

Thank you for your interest in developing interactive applications for `NOVA <https://nova.ornl.gov/>`_. This documentation will guide you through the process of creating a new application and deploying it to NOVA.

Interactive applications for NOVA are developed with the `Trame Framework <https://kitware.github.io/trame/>`_. This framework allows you to build full web applications in Python.

To make it easier to get started, we provide a UI package, :code:`nova-trame`, that should help streamline your development process. All examples in this documentation are based upon this package.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   getting_started
   working_with_trame
   example_layouts
   visualization
   api
   helpful_links
